==> pipenv2deb-2.0.5.tar.gz: pipenv2deb-2.0.5/setup.py <==
import setuptools

MODULE_NAME    = "pipenv2deb"                                                   # The python module name
VERSION        = "2.0.5"                                                        # The version of the application
AUTHOR         = "Paul Austen"                                                  # The name of the applications author
AUTHOR_EMAIL   = "pausten.os@gmail.com"                                         # The email address of the author
DESCRIPTION    = "A tool to produce a deb installer for a python projects that use pipenv." # A short description of the application
LICENSE        = "MIT License"                                                  # The License that the application is distributed under
REQUIRED_LIBS  = []                                                             # A python list of required libs (optionally including versions)
STARTUP_SCRIPTS= ['scripts/pipenv2deb']                                         # The command line startup scripts to be installed.

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name=MODULE_NAME,
    version=VERSION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    description=DESCRIPTION,
    long_description="",                                                        #This will be read from the README.md file
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: {}".format(LICENSE),
        "Operating System :: OS Independent",
    ],
    install_requires=[
        REQUIRED_LIBS
    ],
    scripts=STARTUP_SCRIPTS
)

==> pipenv2deb-2.0.6.tar.gz: pipenv2deb-2.0.6/setup.py <==
import setuptools

MODULE_NAME    = "pipenv2deb"                                                   # The python module name
VERSION        = "2.0.6"                                                        # The version of the application
AUTHOR         = "Paul Austen"                                                  # The name of the applications author
AUTHOR_EMAIL   = "pausten.os@gmail.com"                                         # The email address of the author
DESCRIPTION    = "A tool to produce a deb installer for a python projects that use pipenv." # A short description of the application
LICENSE        = "MIT License"                                                  # The License that the application is distributed under
REQUIRED_LIBS  = []                                                             # A python list of required libs (optionally including versions)
STARTUP_SCRIPTS= ['scripts/pipenv2deb']                                         # The command line startup scripts to be installed.
URL            = "https://github.com/pjaos/pipenv2deb"

with open("README.md", "r") as fh:
    _long_description = fh.read()

setuptools.setup(
    name=MODULE_NAME,
    version=VERSION,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    description=DESCRIPTION,
    long_description=_long_description,                                         #This will be read from the README.md file
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    url=URL,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: {}".format(LICENSE),
        "Operating System :: OS Independent",
    ],
    install_requires=[
        REQUIRED_LIBS
    ],
    scripts=STARTUP_SCRIPTS
)
